@@ -569,30 +569,11 @@ class BlePairing(AbstractPairing):
 
     async def _async_pair_verify(self) -> None:
         async with self._ble_request_lock:
-            # There is only one pair verify characteristic
-            # per device so we can just use the first one
-            # and avoid having to request the iid which speeds
-            # up the pairing resume process
-            try:
-                pair_verify_char = (
-                    self.accessories.aid(BLE_AID)
-                    .services.first(service_type=ServicesTypes.PAIRING)
-                    .characteristics.first(
-                        char_types=[CharacteristicsTypes.PAIR_VERIFY]
-                    )
-                )
-            except StopIteration:
-                # If we don't have a pair verify characteristic yet
-                # it means we haven't fetched the services yet
-                pair_verify_char = None
-
             session_id, derive = await drive_pairing_state_machine(
                 self.client,
                 CharacteristicsTypes.PAIR_VERIFY,
                 get_session_keys(self.pairing_data, self._session_id, self._derive),
-                pair_verify_char.iid if pair_verify_char else None,
             )
-
             self._encryption_key = EncryptionKey(
                 derive(b"Control-Salt", b"Control-Write-Encryption-Key")
             )
@@ -829,7 +810,7 @@ class BlePairing(AbstractPairing):
         accessory.aid = 1
         # Never use the cache when fetching the GATT database
         services_to_link: list[tuple[Service, list[int]]] = []
-        services = await self.client.get_services()
+        services = self.client.services
         for service in services:
             ble_service_char = service.get_characteristic(SERVICE_INSTANCE_ID_UUID)
             if not ble_service_char:
