@@ -155,8 +155,10 @@ class EncryptionContext:
                 "Failed flailing attempts to resynchronize, self-destructing in 3, 2, 1..."
             )
 
-            await self.coap_ctx.shutdown()
-            self.coap_ctx = None
+            if self.coap_ctx:
+                await self.coap_ctx.shutdown()
+                self.coap_ctx = None
+
             raise EncryptionError("Decryption of PDU POST response failed")
 
     async def post_bytes(self, payload: bytes, timeout: int = 16.0):
@@ -170,7 +172,12 @@ class EncryptionContext:
             except (NetworkError, asyncio.TimeoutError):
                 raise AccessoryDisconnectedError("Request timeout")
 
-            if response.code != Code.CHANGED:
+            if response.code == Code.NOT_FOUND:
+                # maybe the accessory lost power or was otherwise rebooted
+                logger.debug("CoAP POST returned 404, our session is gone.")
+                await self.coap_ctx.shutdown()
+                self.coap_ctx = None
+            elif response.code != Code.CHANGED:
                 logger.warning(f"CoAP POST returned unexpected code {response}")
 
             return await self._decrypt_response(response)
