@@ -21,9 +21,19 @@ https://tools.ietf.org/html/rfc7539. See HomeKit spec page 51.
 
 from __future__ import annotations
 
+import logging
+import struct
+
+from chacha20poly1305 import (
+    ChaCha,
+    ChaCha20Poly1305 as ChaCha20Poly1305PurePython,
+    Poly1305,
+)
 from chacha20poly1305_reuseable import ChaCha20Poly1305Reusable
 from cryptography.exceptions import InvalidTag
 
+logger = logging.getLogger(__name__)
+
 
 class ChaCha20Poly1305Encryptor:
     """Encrypt data with ChaCha20Poly1305."""
@@ -93,3 +103,32 @@ class ChaCha20Poly1305Decryptor:
         except InvalidTag:
             # This should raise rather than the callees having to test for False
             return False
+
+
+class ChaCha20Poly1305PartialTag(ChaCha20Poly1305PurePython):
+    def open(self, nonce: bytes, combined_text: bytes, data: bytes) -> bytes:
+        """
+        Decrypts and authenticates ciphertext using nonce and data. If the
+        tag is valid, the plaintext is returned. If the tag is invalid,
+        returns None.
+
+        This decryption only handles ble advertisements, which have a 4 byte
+        partial tag.
+        """
+        if len(nonce) != 12:
+            raise ValueError("Nonce must be 96 bit long")
+
+        expected_tag = combined_text[-4:]
+        ciphertext = combined_text[:-4]
+
+        otk = self.poly1305_key_gen(self.key, nonce)
+
+        mac_data = data + self.pad16(data)
+        mac_data += ciphertext + self.pad16(ciphertext)
+        mac_data += struct.pack("<Q", len(data))
+        mac_data += struct.pack("<Q", len(ciphertext))
+        tag = Poly1305(otk).create_tag(mac_data)
+
+        if not tag.startswith(expected_tag):
+            return None
+        return ChaCha(self.key, nonce, counter=1).decrypt(ciphertext)
